41 static constexpr auto type =
"PRot";
68 using BeamOptic::operator();
108 template<
typename T_Real=amrex::ParticleReal,
typename T_IdCpu=u
int64_t>
133 T_Real
const pz =
sqrt(
162 using Thin::operator();
165 using LinearTransport::operator();
217 R(1,1) = cos_phi_in / cos_phi_out;
218 R(2,2) = cos_phi_out / cos_phi_in;
219 R(2,6) = -sin_theta / (beta * cos_phi_in);
220 R(5,1) = +sin_theta / (beta * cos_phi_out);
#define AMREX_FORCE_INLINE
#define AMREX_GPU_HOST_DEVICE
#define IMPACTX_PUSH_EXTERN_TEMPLATE(ElementType)
Definition PushAll.H:78
T_ParticleType ParticleType
amrex_particle_real ParticleReal
constexpr T powi(T x) noexcept
__host__ __device__ std::pair< double, double > sincos(double x)
__host__ __device__ GpuComplex< T > sqrt(const GpuComplex< T > &a_z) noexcept
Definition alignment.H:25
@ t
fixed t as the independent variable
Definition ImpactXParticleContainer.H:38
amrex::SmallMatrix< amrex::ParticleReal, 6, 6, amrex::Order::F, 1 > Map6x6
Definition CovarianceMatrix.H:20
static constexpr __host__ __device__ SmallMatrix< T, NRows, NCols, ORDER, StartIndex > Identity() noexcept
Definition ReferenceParticle.H:33
AMREX_GPU_HOST_DEVICE AMREX_FORCE_INLINE amrex::ParticleReal beta() const
Definition ReferenceParticle.H:151
amrex::ParticleReal m_cos_theta
Definition PRot.H:231
amrex::ParticleReal m_phi_in
Definition PRot.H:225
static constexpr auto type
Definition PRot.H:41
amrex::ParticleReal m_cos_phi_in
Definition PRot.H:231
AMREX_GPU_HOST_DEVICE AMREX_FORCE_INLINE void operator()(T_Real &AMREX_RESTRICT x, T_Real &AMREX_RESTRICT y, T_Real &AMREX_RESTRICT t, T_Real &AMREX_RESTRICT px, T_Real const &AMREX_RESTRICT py, T_Real const &AMREX_RESTRICT pt, T_IdCpu const &AMREX_RESTRICT idcpu, RefPart const &AMREX_RESTRICT refpart) const
Definition PRot.H:110
AMREX_GPU_HOST AMREX_FORCE_INLINE Map6x6 transport_map(RefPart const &AMREX_RESTRICT refpart) const
Definition PRot.H:201
amrex::ParticleReal m_inv_beta
RF wavenumber in 1/m.
Definition PRot.H:231
void reverse()
Definition PRot.H:65
amrex::ParticleReal m_sin_phi_in
Definition PRot.H:231
amrex::ParticleReal m_phi_out
normalized (max) RF voltage drop.
Definition PRot.H:226
ImpactXParticleContainer::ParticleType PType
Definition PRot.H:42
amrex::ParticleReal m_sin_theta
Definition PRot.H:231
PRot(amrex::ParticleReal phi_in, amrex::ParticleReal phi_out, std::optional< std::string > name=DEFAULT_name)
Definition PRot.H:53
void compute_constants(RefPart const &refpart)
Definition PRot.H:77
Definition beamoptic.H:567
Definition lineartransport.H:50
static constexpr std::nullopt_t DEFAULT_name
Definition named.H:30
AMREX_GPU_HOST Named(std::optional< std::string > name)
Definition named.H:59
AMREX_FORCE_INLINE std::string name() const
Definition named.H:124
Definition nofinalize.H:22